#line 2 "k12text.c"

#line 4 "k12text.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer K12Text__create_buffer
#define yy_delete_buffer K12Text__delete_buffer
#define yy_flex_debug K12Text__flex_debug
#define yy_init_buffer K12Text__init_buffer
#define yy_flush_buffer K12Text__flush_buffer
#define yy_load_buffer_state K12Text__load_buffer_state
#define yy_switch_to_buffer K12Text__switch_to_buffer
#define yyin K12Text_in
#define yyleng K12Text_leng
#define yylex K12Text_lex
#define yylineno K12Text_lineno
#define yyout K12Text_out
#define yyrestart K12Text_restart
#define yytext K12Text_text
#define yywrap K12Text_wrap
#define yyalloc K12Text_alloc
#define yyrealloc K12Text_realloc
#define yyfree K12Text_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE K12Text_restart(K12Text_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int K12Text_leng;

extern FILE *K12Text_in, *K12Text_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up K12Text_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up K12Text_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via K12Text_restart()), so that the user can continue scanning by
	 * just pointing K12Text_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when K12Text_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int K12Text_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow K12Text_wrap()'s to do buffer switches
 * instead of setting up a fresh K12Text_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void K12Text_restart (FILE *input_file  );
void K12Text__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE K12Text__create_buffer (FILE *file,int size  );
void K12Text__delete_buffer (YY_BUFFER_STATE b  );
void K12Text__flush_buffer (YY_BUFFER_STATE b  );
void K12Text_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void K12Text_pop_buffer_state (void );

static void K12Text_ensure_buffer_stack (void );
static void K12Text__load_buffer_state (void );
static void K12Text__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER K12Text__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE K12Text__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE K12Text__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE K12Text__scan_bytes (yyconst char *bytes,int len  );

void *K12Text_alloc (yy_size_t  );
void *K12Text_realloc (void *,yy_size_t  );
void K12Text_free (void *  );

#define yy_new_buffer K12Text__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        K12Text_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            K12Text__create_buffer(K12Text_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        K12Text_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            K12Text__create_buffer(K12Text_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *K12Text_in = (FILE *) 0, *K12Text_out = (FILE *) 0;

typedef int yy_state_type;

extern int K12Text_lineno;

int K12Text_lineno = 1;

extern char *K12Text_text;
#define yytext_ptr K12Text_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up K12Text_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	K12Text_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 20
#define YY_END_OF_BUFFER 21
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[509] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   21,   19,
       20,    2,    2,   19,   19,   19,    6,   19,    8,   19,
       10,   19,   19,   19,   19,   19,   20,   19,   19,   19,
        0,    0,    0,    4,    5,    7,    0,    0,    0,    0,
        0,    0,   18,    0,    0,    0,    0,    0,    0,    9,
       11,    0,    0,    0,    0,   16,    0,    0,    0,    0,
       14,   13,    0,    0,    0,    0,   12,    0,    0,    0,
        0,   15,   17,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    1,    0,    0,
        3,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    3,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    6,    7,    1,    1,    8,    9,    9,
        9,    9,    9,    9,    9,    9,    9,   10,    1,    1,
        1,    1,    1,    1,   11,   11,   12,   13,   14,   15,
        1,   16,    1,    1,    1,   17,    1,    1,    1,    1,
        1,   18,   19,   20,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   21,   21,   21,   21,

       21,   21,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   22,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[23] =
    {   0,
        1,    1,    1,    2,    1,    1,    1,    3,    3,    1,
        3,    3,    3,    3,    3,    1,    1,    1,    1,    1,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[515] =
    {   0,
      898,  897,    0,    1,    2,    6,    7,   10,   12,   15,
       20,   23,   26,   29,   30,   37,   38,   40,   39,   48,
       49,   51,   59,    0,   42,   50,   80,    0,  898,  901,
      901,  901,  890,  889,   57,   18,  901,   47,  901,   54,
      901,   60,  875,  881,  874,  884,   68,  889,   71,    0,
      883,  882,   76,  901,  901,  901,   68,   82,  872,  870,
      874,  881,  901,  882,   91,  861,    0,  875,  874,  901,
      901,  866,  867,  863,  873,  901,    0,  869,  868,  856,
      901,  901,  869,    0,  865,  864,  901,  848,  847,  861,
      860,  901,  901,  859,  858,  857,  856,  855,  854,  855,

      854,  851,  850,  849,  848,  847,  846,  845,  844,  843,
      842,  841,  840,  839,  838,  837,  836,  835,  834,  833,
      832,  831,  830,  829,  828,  827,  826,  825,  824,  823,
      822,   90,   91,  821,   98,  820,   99,  819,  102,  818,
      103,  817,  106,  816,  107,  815,  110,  814,  111,  813,
      114,  812,  115,  811,  118,  810,  119,  809,  122,  808,
      123,  807,  126,  806,  127,  805,  130,  804,  131,   93,
      134,   92,  135,  138,  139,  142,  143,  901,  146,  147,
      901,  150,  151,  154,  155,  158,  159,  162,  163,  166,
      167,  170,  171,  174,  175,  178,  179,  182,  183,  186,

      187,  190,  191,  194,  195,  198,  199,  202,  203,  206,
      207,  210,  211,  214,  215,  218,  219,  222,  223,  226,
      227,  230,  231,  234,  235,  238,  239,  242,  243,  246,
      247,  250,  251,  254,  255,  258,  259,  262,  263,  266,
      267,  270,  271,  274,  275,  278,  279,  282,  283,  286,
      287,  290,  291,  294,  295,  298,  299,  302,  303,  306,
      307,  310,  311,  314,  315,  318,  319,  322,  323,  326,
      327,  330,  331,  334,  335,  338,  339,  342,  343,  346,
      347,  350,  351,  354,  355,  358,  359,  362,  363,  366,
      367,  370,  371,  374,  375,  378,  379,  382,  383,  386,

      387,  390,  391,  394,  395,  398,  399,  402,  403,  406,
      407,  410,  411,  414,  415,  418,  419,  422,  423,  426,
      427,  430,  431,  434,  435,  438,  439,  442,  443,  446,
      447,  450,  451,  454,  455,  458,  459,  462,  463,  466,
      467,  470,  471,  474,  475,  478,  479,  482,  483,  486,
      487,  490,  491,  494,  495,  498,  499,  502,  503,  506,
      507,  510,  511,  514,  515,  518,  519,  522,  523,  526,
      527,  530,  531,  534,  535,  538,  539,  542,  543,  546,
      547,  550,  551,  554,  555,  558,  559,  562,  563,  566,
      567,  570,  571,  574,  575,  578,  579,  582,  583,  586,

      587,  590,  591,  594,  595,  598,  599,  602,  603,  606,
      607,  610,  611,  614,  615,  618,  619,  622,  623,  626,
      627,  630,  631,  634,  635,  638,  639,  642,  643,  646,
      647,  650,  651,  654,  655,  658,  659,  662,  663,  666,
      667,  670,  671,  674,  675,  678,  679,  682,  683,  686,
      687,  690,  691,  694,  695,  698,  699,  702,  703,  706,
      707,  710,  711,  714,  715,  718,  719,  722,  723,  726,
      727,  730,   82,  731,   69,  734,  735,  738,  739,  742,
      743,  746,  747,  750,  751,  754,  755,  758,  759,  762,
      763,  766,  767,  770,  771,  774,  775,  778,  779,  782,

      783,  786,  787,  790,  791,   24,    8,  901,  798,  801,
        7,  803,  805,  807
    } ;

static yyconst flex_int16_t yy_def[515] =
    {   0,
      509,  509,  510,  510,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,   23,  509,  509,  509,   27,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  511,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  512,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  513,  508,  508,  508,
      508,  508,  508,  514,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  508,  508,  508,  508,    0,  508,  508,
      508,  508,  508,  508
    } ;

static yyconst flex_int16_t yy_nxt[924] =
    {   0,
      508,   31,   31,   31,   33,   33,   34,   31,   31,   67,
       34,   31,  181,   31,   35,   35,   31,   35,   35,   36,
       36,   31,   36,   36,   31,   55,   55,   31,  178,   37,
       31,   31,   37,   38,   38,   39,   38,   38,   31,   31,
       31,   31,   39,   31,   41,   40,   40,   40,   40,   31,
       31,   31,   31,   41,   56,   56,   42,   42,   42,   42,
       31,   57,   57,   46,   53,   53,   54,   58,   58,   63,
       64,   46,   43,  136,   44,   70,   70,   45,   66,   66,
       46,   47,   48,   53,   53,   54,  134,   49,   49,   71,
       71,   66,   63,   64,  134,  136,  135,  137,  176,  174,

       49,   50,  134,  136,  139,  141,  134,  136,  143,  145,
      134,  136,  147,  149,  134,  136,  151,  153,  134,  136,
      155,  157,  134,  136,  159,  161,  134,  136,  163,  165,
      134,  136,  167,  169,  134,  136,  171,  173,  134,  136,
      175,  177,  178,  134,  179,  180,  181,  136,  182,  183,
      178,  134,  184,  185,  181,  136,  186,  187,  178,  134,
      188,  189,  181,  136,  190,  191,  178,  134,  192,  193,
      181,  136,  194,  195,  178,  134,  196,  197,  181,  136,
      198,  199,  178,  134,  200,  201,  181,  136,  202,  203,
      178,  134,  204,  205,  181,  136,  206,  207,  178,  134,

      208,  209,  181,  136,  210,  211,  178,  134,  212,  213,
      181,  136,  214,  215,  178,  134,  216,  217,  181,  136,
      218,  219,  178,  134,  220,  221,  181,  136,  222,  223,
      178,  134,  224,  225,  181,  136,  226,  227,  178,  134,
      228,  229,  181,  136,  230,  231,  178,  134,  232,  233,
      181,  136,  234,  235,  178,  134,  236,  237,  181,  136,
      238,  239,  178,  134,  240,  241,  181,  136,  242,  243,
      178,  134,  244,  245,  181,  136,  246,  247,  178,  134,
      248,  249,  181,  136,  250,  251,  178,  134,  252,  253,
      181,  136,  254,  255,  178,  134,  256,  257,  181,  136,

      258,  259,  178,  134,  260,  261,  181,  136,  262,  263,
      178,  134,  264,  265,  181,  136,  266,  267,  178,  134,
      268,  269,  181,  136,  270,  271,  178,  134,  272,  273,
      181,  136,  274,  275,  178,  134,  276,  277,  181,  136,
      278,  279,  178,  134,  280,  281,  181,  136,  282,  283,
      178,  134,  284,  285,  181,  136,  286,  287,  178,  134,
      288,  289,  181,  136,  290,  291,  178,  134,  292,  293,
      181,  136,  294,  295,  178,  134,  296,  297,  181,  136,
      298,  299,  178,  134,  300,  301,  181,  136,  302,  303,
      178,  134,  304,  305,  181,  136,  306,  307,  178,  134,

      308,  309,  181,  136,  310,  311,  178,  134,  312,  313,
      181,  136,  314,  315,  178,  134,  316,  317,  181,  136,
      318,  319,  178,  134,  320,  321,  181,  136,  322,  323,
      178,  134,  324,  325,  181,  136,  326,  327,  178,  134,
      328,  329,  181,  136,  330,  331,  178,  134,  332,  333,
      181,  136,  334,  335,  178,  134,  336,  337,  181,  136,
      338,  339,  178,  134,  340,  341,  181,  136,  342,  343,
      178,  134,  344,  345,  181,  136,  346,  347,  178,  134,
      348,  349,  181,  136,  350,  351,  178,  134,  352,  353,
      181,  136,  354,  355,  178,  134,  356,  357,  181,  136,

      358,  359,  178,  134,  360,  361,  181,  136,  362,  363,
      178,  134,  364,  365,  181,  136,  366,  367,  178,  134,
      368,  369,  181,  136,  370,  371,  178,  134,  372,  373,
      181,  136,  374,  375,  178,  134,  376,  377,  181,  136,
      378,  379,  178,  134,  380,  381,  181,  136,  382,  383,
      178,  134,  384,  385,  181,  136,  386,  387,  178,  134,
      388,  389,  181,  136,  390,  391,  178,  134,  392,  393,
      181,  136,  394,  395,  178,  134,  396,  397,  181,  136,
      398,  399,  178,  134,  400,  401,  181,  136,  402,  403,
      178,  134,  404,  405,  181,  136,  406,  407,  178,  134,

      408,  409,  181,  136,  410,  411,  178,  134,  412,  413,
      181,  136,  414,  415,  178,  134,  416,  417,  181,  136,
      418,  419,  178,  134,  420,  421,  181,  136,  422,  423,
      178,  134,  424,  425,  181,  136,  426,  427,  178,  134,
      428,  429,  181,  136,  430,  431,  178,  134,  432,  433,
      181,  136,  434,  435,  178,  134,  436,  437,  181,  136,
      438,  439,  178,  134,  440,  441,  181,  136,  442,  443,
      178,  134,  444,  445,  181,  136,  446,  447,  178,  134,
      448,  449,  181,  136,  450,  451,  178,  134,  452,  453,
      181,  136,  454,  455,  178,  134,  456,  457,  181,  136,

      458,  459,  178,  134,  460,  461,  181,  136,  462,  463,
      178,  134,  464,  465,  181,  136,  466,  467,  178,  134,
      468,  469,  181,  136,  470,  471,  178,  134,  472,  473,
      181,  136,  474,  475,  178,  181,  476,  477,  178,  181,
      478,  479,  178,  181,  480,  481,  178,  181,  482,  483,
      178,  181,  484,  485,  178,  181,  486,  487,  178,  181,
      488,  489,  178,  181,  490,  491,  178,  181,  492,  493,
      178,  181,  494,  495,  178,  181,  496,  497,  178,  181,
      498,  499,  178,  181,  500,  501,  178,  181,  502,  503,
      178,  181,  504,  505,  178,  181,  506,  507,   30,   30,

       30,   32,   32,   32,   77,   77,   84,   84,   89,   89,
      172,  170,  168,  166,  164,  162,  160,  158,  156,  154,
      152,  150,  148,  146,  144,  142,  140,  138,  133,  132,
      131,  130,  129,  128,  127,  126,  125,  124,  123,  122,
      121,  120,  119,  118,  117,  116,  115,  114,  113,  112,
      111,  110,  109,  108,  107,  106,  105,  104,  103,  102,
      101,  100,   99,   98,   97,   96,   95,   94,   93,   92,
       91,   90,   88,   87,   86,   85,   83,   82,   81,   80,
       79,   78,   76,   63,   75,   74,   73,   72,   69,   68,
       65,   62,   61,   60,   59,   52,   51,  508,   31,   31,

       29,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508
    } ;

static yyconst flex_int16_t yy_chk[924] =
    {   0,
        0,    3,    4,    5,    3,    4,    5,    6,    7,  511,
        6,    8,  507,    9,    7,    7,   10,    8,    8,    9,
        9,   11,   10,   10,   12,   36,   36,   13,  506,   11,
       14,   15,   12,   13,   13,   15,   14,   14,   16,   17,
       19,   18,   16,   25,   19,   17,   17,   18,   18,   20,
       21,   26,   22,   20,   38,   38,   21,   21,   22,   22,
       23,   40,   40,   25,   35,   35,   35,   42,   42,   47,
       47,   26,   23,  475,   23,   57,   57,   23,   49,   49,
       23,   27,   27,   53,   53,   53,  473,   27,   27,   58,
       58,   49,   65,   65,  132,  133,  132,  133,  172,  170,

       27,   27,  135,  137,  135,  137,  139,  141,  139,  141,
      143,  145,  143,  145,  147,  149,  147,  149,  151,  153,
      151,  153,  155,  157,  155,  157,  159,  161,  159,  161,
      163,  165,  163,  165,  167,  169,  167,  169,  171,  173,
      171,  173,  174,  175,  174,  175,  176,  177,  176,  177,
      179,  180,  179,  180,  182,  183,  182,  183,  184,  185,
      184,  185,  186,  187,  186,  187,  188,  189,  188,  189,
      190,  191,  190,  191,  192,  193,  192,  193,  194,  195,
      194,  195,  196,  197,  196,  197,  198,  199,  198,  199,
      200,  201,  200,  201,  202,  203,  202,  203,  204,  205,

      204,  205,  206,  207,  206,  207,  208,  209,  208,  209,
      210,  211,  210,  211,  212,  213,  212,  213,  214,  215,
      214,  215,  216,  217,  216,  217,  218,  219,  218,  219,
      220,  221,  220,  221,  222,  223,  222,  223,  224,  225,
      224,  225,  226,  227,  226,  227,  228,  229,  228,  229,
      230,  231,  230,  231,  232,  233,  232,  233,  234,  235,
      234,  235,  236,  237,  236,  237,  238,  239,  238,  239,
      240,  241,  240,  241,  242,  243,  242,  243,  244,  245,
      244,  245,  246,  247,  246,  247,  248,  249,  248,  249,
      250,  251,  250,  251,  252,  253,  252,  253,  254,  255,

      254,  255,  256,  257,  256,  257,  258,  259,  258,  259,
      260,  261,  260,  261,  262,  263,  262,  263,  264,  265,
      264,  265,  266,  267,  266,  267,  268,  269,  268,  269,
      270,  271,  270,  271,  272,  273,  272,  273,  274,  275,
      274,  275,  276,  277,  276,  277,  278,  279,  278,  279,
      280,  281,  280,  281,  282,  283,  282,  283,  284,  285,
      284,  285,  286,  287,  286,  287,  288,  289,  288,  289,
      290,  291,  290,  291,  292,  293,  292,  293,  294,  295,
      294,  295,  296,  297,  296,  297,  298,  299,  298,  299,
      300,  301,  300,  301,  302,  303,  302,  303,  304,  305,

      304,  305,  306,  307,  306,  307,  308,  309,  308,  309,
      310,  311,  310,  311,  312,  313,  312,  313,  314,  315,
      314,  315,  316,  317,  316,  317,  318,  319,  318,  319,
      320,  321,  320,  321,  322,  323,  322,  323,  324,  325,
      324,  325,  326,  327,  326,  327,  328,  329,  328,  329,
      330,  331,  330,  331,  332,  333,  332,  333,  334,  335,
      334,  335,  336,  337,  336,  337,  338,  339,  338,  339,
      340,  341,  340,  341,  342,  343,  342,  343,  344,  345,
      344,  345,  346,  347,  346,  347,  348,  349,  348,  349,
      350,  351,  350,  351,  352,  353,  352,  353,  354,  355,

      354,  355,  356,  357,  356,  357,  358,  359,  358,  359,
      360,  361,  360,  361,  362,  363,  362,  363,  364,  365,
      364,  365,  366,  367,  366,  367,  368,  369,  368,  369,
      370,  371,  370,  371,  372,  373,  372,  373,  374,  375,
      374,  375,  376,  377,  376,  377,  378,  379,  378,  379,
      380,  381,  380,  381,  382,  383,  382,  383,  384,  385,
      384,  385,  386,  387,  386,  387,  388,  389,  388,  389,
      390,  391,  390,  391,  392,  393,  392,  393,  394,  395,
      394,  395,  396,  397,  396,  397,  398,  399,  398,  399,
      400,  401,  400,  401,  402,  403,  402,  403,  404,  405,

      404,  405,  406,  407,  406,  407,  408,  409,  408,  409,
      410,  411,  410,  411,  412,  413,  412,  413,  414,  415,
      414,  415,  416,  417,  416,  417,  418,  419,  418,  419,
      420,  421,  420,  421,  422,  423,  422,  423,  424,  425,
      424,  425,  426,  427,  426,  427,  428,  429,  428,  429,
      430,  431,  430,  431,  432,  433,  432,  433,  434,  435,
      434,  435,  436,  437,  436,  437,  438,  439,  438,  439,
      440,  441,  440,  441,  442,  443,  442,  443,  444,  445,
      444,  445,  446,  447,  446,  447,  448,  449,  448,  449,
      450,  451,  450,  451,  452,  453,  452,  453,  454,  455,

      454,  455,  456,  457,  456,  457,  458,  459,  458,  459,
      460,  461,  460,  461,  462,  463,  462,  463,  464,  465,
      464,  465,  466,  467,  466,  467,  468,  469,  468,  469,
      470,  471,  470,  471,  472,  474,  472,  474,  476,  477,
      476,  477,  478,  479,  478,  479,  480,  481,  480,  481,
      482,  483,  482,  483,  484,  485,  484,  485,  486,  487,
      486,  487,  488,  489,  488,  489,  490,  491,  490,  491,
      492,  493,  492,  493,  494,  495,  494,  495,  496,  497,
      496,  497,  498,  499,  498,  499,  500,  501,  500,  501,
      502,  503,  502,  503,  504,  505,  504,  505,  509,  509,

      509,  510,  510,  510,  512,  512,  513,  513,  514,  514,
      168,  166,  164,  162,  160,  158,  156,  154,  152,  150,
      148,  146,  144,  142,  140,  138,  136,  134,  131,  130,
      129,  128,  127,  126,  125,  124,  123,  122,  121,  120,
      119,  118,  117,  116,  115,  114,  113,  112,  111,  110,
      109,  108,  107,  106,  105,  104,  103,  102,  101,  100,
       99,   98,   97,   96,   95,   94,   91,   90,   89,   88,
       86,   85,   83,   80,   79,   78,   75,   74,   73,   72,
       69,   68,   66,   64,   62,   61,   60,   59,   52,   51,
       48,   46,   45,   44,   43,   34,   33,   29,    2,    1,

      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int K12Text__flex_debug;
int K12Text__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *K12Text_text;
#line 1 "k12text.l"
/*
 * We don't use unput, so don't generate code for it.
 */
/*
 * We don't read from the terminal.
 */
/*
 * Prefix scanner routines with "K12Text_" rather than "yy", so this scanner
 * can coexist with other scanners.
 */
/* Options useful for debugging                    */
/* noline:  Prevent generation of #line directives */
/*          Seems to be required when using the    */
/*           Windows VS debugger so as to be able  */
/*           to properly step through the code and */
/*           set breakpoints & etc using the       */
/*           k12text.c file rather than the        */
/*           k12text.l file                        */
/*     XXX: %option noline gives an error message: */
/*          "unrecognized %option: line"           */
/*          with flex 2.5.35; the --noline         */
/*          command-line option works OK.          */
/*                                                 */
/* debug:   Do output of "rule acceptance" info    */
/*           during parse                          */ 
/*                                                 */
/* %option noline  */
/* %option debug   */
#line 39 "k12text.l"
/* k12text.l
 *
 * $Id: k12text.l 27231 2009-01-14 20:50:39Z wmeier $
 *
 * Wiretap Library
 * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

 /*
  * TODO:
  *   - fix timestamps after midnight
  *   - verify encapsulations
  */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <time.h>
#include "wtap-int.h"
#include "wtap.h"
#include "file_wrappers.h"
#include "buffer.h"
#include "k12.h"
#include "k12text_lex.h"

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

static guint h;
static guint m;
static guint s;
static guint ms;
static guint ns;
static gint encap;
static guint8 b[WTAP_MAX_PACKET_SIZE];
static guint i;
static gboolean is_k12text;
static gboolean at_eof;
static guint junk_chars;
static void finalize_frame(void);
static gchar* error_str;
static guint file_bytes_read;
static gboolean ok_frame;
static FILE_T yy_fh;

#define KERROR(text) do { error_str = g_strdup(text); yyterminate(); } while(0)
#define SET_HOURS(text) h = strtoul(text,NULL,10)
#define SET_MINUTES(text) m = strtoul(text,NULL,10)
#define SET_SECONDS(text) s = strtoul(text,NULL,10)
#define SET_MS(text) ms = strtoul(text,NULL,10)
#define SET_NS(text) ns = strtoul(text,NULL,10)
#define ADD_BYTE(text) do {if (i >= WTAP_MAX_PACKET_SIZE) {KERROR("frame too large");} b[i++] = (guint8)strtoul(text,NULL,16); } while(0)
#define FINALIZE_FRAME() finalize_frame()
/*~ #define ECHO*/
#define YY_USER_ACTION file_bytes_read += K12Text_leng;
#define YY_INPUT(buf,result,max_size) { int c = file_getc(yy_fh);  result = (c==EOF) ? YY_NULL : (buf[0] = c, 1); }

#define MAX_JUNK 400000
#define ECHO
/* mtp2 MTP-L2 ;; XXX: Not supported until it's determined how to fill in the pseudo_header req'd by packet-mtp2 */
/* sscop SSCOP ;; XXX: Not supported until it's determined how to fill in the pseudo_header req'd by packet-atm  */

#line 958 "k12text.c"

#define INITIAL 0
#define MAGIC 1
#define NEXT_FRAME 2
#define HOURS 3
#define MINUTES 4
#define M2S 5
#define SECONDS 6
#define S2M 7
#define MS 8
#define M2N 9
#define NS 10
#define ENCAP 11
#define STARTBYTES 12
#define BYTE 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int K12Text_lex_destroy (void );

int K12Text_get_debug (void );

void K12Text_set_debug (int debug_flag  );

YY_EXTRA_TYPE K12Text_get_extra (void );

void K12Text_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *K12Text_get_in (void );

void K12Text_set_in  (FILE * in_str  );

FILE *K12Text_get_out (void );

void K12Text_set_out  (FILE * out_str  );

int K12Text_get_leng (void );

char *K12Text_get_text (void );

int K12Text_get_lineno (void );

void K12Text_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int K12Text_wrap (void );
#else
extern int K12Text_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( K12Text_text, K12Text_leng, 1, K12Text_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( K12Text_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( K12Text_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, K12Text_in))==0 && ferror(K12Text_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(K12Text_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int K12Text_lex (void);

#define YY_DECL int K12Text_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after K12Text_text and K12Text_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 134 "k12text.l"

#line 1158 "k12text.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! K12Text_in )
			K12Text_in = stdin;

		if ( ! K12Text_out )
			K12Text_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			K12Text_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				K12Text__create_buffer(K12Text_in,YY_BUF_SIZE );
		}

		K12Text__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of K12Text_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 509 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 508 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 135 "k12text.l"
{ is_k12text = TRUE; yyterminate(); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 137 "k12text.l"
{ if (++ junk_chars > MAX_JUNK) { is_k12text = FALSE;  yyterminate(); } }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 139 "k12text.l"
{BEGIN(HOURS); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 140 "k12text.l"
{ SET_HOURS(K12Text_text); BEGIN(MINUTES); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 141 "k12text.l"
{ SET_MINUTES(K12Text_text); BEGIN(M2S);}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 142 "k12text.l"
{ BEGIN(SECONDS);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 143 "k12text.l"
{ SET_SECONDS(K12Text_text); BEGIN(S2M); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 144 "k12text.l"
{ BEGIN(MS); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 145 "k12text.l"
{ SET_MS(K12Text_text); BEGIN(M2N);  }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 146 "k12text.l"
{ BEGIN(NS); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 147 "k12text.l"
{ SET_NS(K12Text_text); BEGIN(ENCAP);}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 148 "k12text.l"
{encap = WTAP_ENCAP_ETHERNET; BEGIN(STARTBYTES); }
	YY_BREAK
/* <ENCAP>{mtp2} {encap = WTAP_ENCAP_MTP2; BEGIN(STARTBYTES); }      Not supported as yet */
/* <ENCAP>{sscop} {encap = WTAP_ENCAP_ATM_PDUS; BEGIN(STARTBYTES); } Not supported as yet */
case 13:
YY_RULE_SETUP
#line 151 "k12text.l"
{encap = WTAP_ENCAP_MTP3; BEGIN(STARTBYTES); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 152 "k12text.l"
{encap = WTAP_ENCAP_CHDLC; BEGIN(STARTBYTES); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 153 "k12text.l"
{ BEGIN(BYTE); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 154 "k12text.l"
{ ADD_BYTE(K12Text_text); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 155 "k12text.l"
;
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 156 "k12text.l"
{ FINALIZE_FRAME(); yyterminate(); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 158 "k12text.l"
{  if (++junk_chars > MAX_JUNK) { KERROR("too much junk");  } }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(MAGIC):
case YY_STATE_EOF(NEXT_FRAME):
case YY_STATE_EOF(HOURS):
case YY_STATE_EOF(MINUTES):
case YY_STATE_EOF(M2S):
case YY_STATE_EOF(SECONDS):
case YY_STATE_EOF(S2M):
case YY_STATE_EOF(MS):
case YY_STATE_EOF(M2N):
case YY_STATE_EOF(NS):
case YY_STATE_EOF(ENCAP):
case YY_STATE_EOF(STARTBYTES):
case YY_STATE_EOF(BYTE):
#line 159 "k12text.l"
{ at_eof = TRUE; yyterminate(); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 161 "k12text.l"
ECHO;
	YY_BREAK
#line 1357 "k12text.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed K12Text_in at a new source and called
			 * K12Text_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = K12Text_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( K12Text_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * K12Text_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of K12Text_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					K12Text_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			K12Text_restart(K12Text_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) K12Text_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 509 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 509 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 508);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					K12Text_restart(K12Text_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( K12Text_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve K12Text_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void K12Text_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        K12Text_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            K12Text__create_buffer(K12Text_in,YY_BUF_SIZE );
	}

	K12Text__init_buffer(YY_CURRENT_BUFFER,input_file );
	K12Text__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void K12Text__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		K12Text_pop_buffer_state();
	 *		K12Text_push_buffer_state(new_buffer);
     */
	K12Text_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	K12Text__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (K12Text_wrap()) processing, but the only time this flag
	 * is looked at is after K12Text_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void K12Text__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	K12Text_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE K12Text__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) K12Text_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in K12Text__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) K12Text_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in K12Text__create_buffer()" );

	b->yy_is_our_buffer = 1;

	K12Text__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with K12Text__create_buffer()
 * 
 */
    void K12Text__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		K12Text_free((void *) b->yy_ch_buf  );

	K12Text_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a K12Text_restart() or at EOF.
 */
    static void K12Text__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	K12Text__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then K12Text__init_buffer was _probably_
     * called from K12Text_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void K12Text__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		K12Text__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void K12Text_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	K12Text_ensure_buffer_stack();

	/* This block is copied from K12Text__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from K12Text__switch_to_buffer. */
	K12Text__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void K12Text_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	K12Text__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		K12Text__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void K12Text_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)K12Text_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in K12Text_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)K12Text_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in K12Text_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE K12Text__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) K12Text_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in K12Text__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	K12Text__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to K12Text_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       K12Text__scan_bytes() instead.
 */
YY_BUFFER_STATE K12Text__scan_string (yyconst char * yystr )
{
    
	return K12Text__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to K12Text_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE K12Text__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) K12Text_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in K12Text__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = K12Text__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in K12Text__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up K12Text_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		K12Text_text[K12Text_leng] = (yy_hold_char); \
		(yy_c_buf_p) = K12Text_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		K12Text_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int K12Text_get_lineno  (void)
{
        
    return K12Text_lineno;
}

/** Get the input stream.
 * 
 */
FILE *K12Text_get_in  (void)
{
        return K12Text_in;
}

/** Get the output stream.
 * 
 */
FILE *K12Text_get_out  (void)
{
        return K12Text_out;
}

/** Get the length of the current token.
 * 
 */
int K12Text_get_leng  (void)
{
        return K12Text_leng;
}

/** Get the current token.
 * 
 */

char *K12Text_get_text  (void)
{
        return K12Text_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void K12Text_set_lineno (int  line_number )
{
    
    K12Text_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see K12Text__switch_to_buffer
 */
void K12Text_set_in (FILE *  in_str )
{
        K12Text_in = in_str ;
}

void K12Text_set_out (FILE *  out_str )
{
        K12Text_out = out_str ;
}

int K12Text_get_debug  (void)
{
        return K12Text__flex_debug;
}

void K12Text_set_debug (int  bdebug )
{
        K12Text__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from K12Text_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    K12Text_in = stdin;
    K12Text_out = stdout;
#else
    K12Text_in = (FILE *) 0;
    K12Text_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * K12Text_lex_init()
     */
    return 0;
}

/* K12Text_lex_destroy is for both reentrant and non-reentrant scanners. */
int K12Text_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		K12Text__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		K12Text_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	K12Text_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * K12Text_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *K12Text_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *K12Text_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void K12Text_free (void * ptr )
{
	free( (char *) ptr );	/* see K12Text_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 161 "k12text.l"



static void finalize_frame(void) {
	ok_frame = TRUE;
}

/* Fill in pseudo-header according to the encapsulation type             */

static void k12text_set_pseudo_header(wtap *wth, union wtap_pseudo_header *pseudo_header) {
	/* The file-encap is WTAP_ENCAP_PER_PACKET */
	switch(wth->phdr.pkt_encap) {
	    case WTAP_ENCAP_ETHERNET:
		    pseudo_header->eth.fcs_len = 0;
		    break;
	    case WTAP_ENCAP_MTP3:
	    case WTAP_ENCAP_CHDLC:
		    /* no pseudo_header to fill in for these types */
		    break;
#if 0
	    case WTAP_ENCAP_MTP2:      /* not (yet) supported       */
	    case WTAP_ENCAP_ATM_PDUS:  /* not (yet) supported       */
		    /* XXX: I don't know how to fill in the         */
                    /* pseudo_header for these types. So: The Lexer */
                    /* has recognition for these types commented    */
		    /* out ....                                     */
		    break;
#endif
	    case WTAP_ENCAP_UNKNOWN:
	    default:
		    break;
	}
}

/* Note: k12text_reset is called each time data is to be processed from  */
/*       a file. This ensures that no "state" from a previous read is    */
/*       used (such as the lexer look-ahead buffer, file_handle, file    */
/*       position and so on. This allows a single lexer buffer to be     */
/*       used even when multiple files are open simultaneously (as for   */
/*       a file merge).                                                  */

static void k12text_reset(FILE_T fh) {
	yy_fh = fh;
	K12Text_restart(0);
	encap = WTAP_ENCAP_UNKNOWN;
	ok_frame = FALSE;
	is_k12text = FALSE;
	at_eof = FALSE;
	junk_chars = 0;
	error_str = NULL;
	file_bytes_read=0;
	h=0;
	m=0;
	s=0;
	ns=0;
	ms=0;
	i=0;
}

static gboolean k12text_read(wtap *wth, int *err, char ** err_info, gint64 *data_offset) {

	/* We seek to the file position after the end of the previous frame processed by         */
	/* k12text_read (kept in wth->data_offset). We do this each time since the lexer         */
	/* undoubtedly did some amount of look-ahead when processing the previous frame.         */ 
	/* We also clear out any lexer state (eg: look-ahead buffer) and init vars set by lexer. */

	if ( file_seek(wth->fh, wth->data_offset, SEEK_SET, err) == -1) {
		return FALSE;
	}
	k12text_reset(wth->fh);          /* init lexer buffer and vars set by lexer */

	BEGIN(NEXT_FRAME);
	K12Text_lex();

	if (ok_frame == FALSE) {
		if (at_eof) {
			*err_info = NULL;
			*err = 0;
		} else {
			*err_info = error_str;
			*err = WTAP_ERR_BAD_RECORD;
		}
		return FALSE;
	}

	*data_offset = wth->data_offset;       /* file position for beginning of this frame   */
	wth->data_offset += file_bytes_read;   /* file position after end of this frame       */

	wth->phdr.ts.secs = 946681200 + (3600*h) + (60*m) + s;
	wth->phdr.ts.nsecs = 1000000*ms + 1000*ns;

	wth->phdr.caplen = wth->phdr.len = i;

	wth->phdr.pkt_encap = encap;
	k12text_set_pseudo_header(wth, &wth->pseudo_header);

	buffer_assure_space(wth->frame_buffer, wth->phdr.caplen);
	memcpy(buffer_start_ptr(wth->frame_buffer), b, wth->phdr.caplen);

	return TRUE;
}

static gboolean k12text_seek_read(wtap *wth, gint64 seek_off, union wtap_pseudo_header *pseudo_header, guint8 *pd, int length, int *err, char **err_info) {

	if ( file_seek(wth->random_fh, seek_off, SEEK_SET, err) == -1) {
		return FALSE;
	}
	k12text_reset(wth->random_fh);            /* init lexer buffer and vars set by lexer */

	BEGIN(NEXT_FRAME);
	K12Text_lex();

	if (ok_frame == FALSE) {
		if (at_eof) {
			/* What happened ? The desired frame was previously read without a problem */
			*err_info = g_strdup("Unexpected EOF (program error ?)");
		} else {
			*err_info = error_str;
		}
		*err = WTAP_ERR_BAD_RECORD;
		return FALSE;
	}

	/* verify frame length parsed this time against original frame length */
	if (i != (guint)length) {
		/* What happened ? This now seems to have a different length than originally */
		*err_info = g_strdup("Incorrect frame length (program error ?)");
		*err = WTAP_ERR_BAD_RECORD;
		return FALSE;
	}

	k12text_set_pseudo_header(wth, pseudo_header);

	memcpy(pd, b, length);

	return TRUE;
}

static void k12text_close(wtap *wth _U_) {
	(void)0;
}

int k12text_open(wtap *wth, int *err, gchar **err_info _U_) {

	k12text_reset(wth->fh);       /* init lexer buffer and vars set by lexer */

	BEGIN(MAGIC);
	K12Text_lex();

	if (! is_k12text) return 0;

	if ( file_seek(wth->fh, 0, SEEK_SET, err) == -1) {
		return -1;
	}

	wth->data_offset = 0;
	wth->file_type = WTAP_FILE_K12TEXT;
	wth->file_encap = WTAP_ENCAP_PER_PACKET;
	wth->snapshot_length = 0;
	wth->subtype_read = k12text_read;
	wth->subtype_seek_read = k12text_seek_read;
	wth->subtype_close = k12text_close;
	wth->capture.generic  = NULL;
	wth->tsprecision = WTAP_FILE_TSPREC_NSEC;

	return 1;
}


static const struct { int e; const char* s; } encaps[] = {
	{ WTAP_ENCAP_ETHERNET, "ETHER" },
	{ WTAP_ENCAP_MTP2, "MTP-L2" },
	{ WTAP_ENCAP_ATM_PDUS, "SSCOP" },
	{ WTAP_ENCAP_MTP3, "SSCF" },
	{ WTAP_ENCAP_CHDLC, "HDLC" },
	/* ... */
	{ WTAP_ENCAP_UNKNOWN, "UNKNOWN" },
	{ 0, NULL }
};

static gboolean k12text_dump(wtap_dumper *wdh _U_, const struct wtap_pkthdr *phdr,
                         const union wtap_pseudo_header *pseudo_header _U_,
                         const guchar *pd, int *err _U_) {
	char buf[196808];
	size_t left = 196808;
	gint wl;
	char* p=buf;
	const char* str_enc = "";
	guint i;
	guint ns;
	guint ms;

	ms = phdr->ts.nsecs / 1000000;
	ns = (phdr->ts.nsecs - (1000000*ms))/1000;

	for(i=0; encaps[i].s; i++) {
		str_enc = encaps[i].s;
		if (phdr->pkt_encap == encaps[i].e) break;
	}

	strftime(p,90,"+---------+---------------+----------+\r\n%H:%M:%S,",gmtime(&phdr->ts.secs));
       wl = strlen(p);
       p += wl;
       left -= wl;
       
       wl = g_snprintf(p,left,"%.3d,%.3d   %s\r\n|0   |",ms,ns,str_enc);
       p+= wl;
       left -= wl;

       for(i=0;i < phdr->caplen && left > 2; i++) {
               wl = g_snprintf(p,left,"%.2x|",pd[i]);
               p += wl;
               left -= wl;
		}

       wl = g_snprintf(p,left,"\r\n\r\n");
       p+= wl;
       left -= wl;
       
	fwrite(buf, 1, strlen(buf), wdh->fh);

	return TRUE;
}


static gboolean k12text_dump_close(wtap_dumper *wdh _U_ , int *err _U_) {
	return TRUE;
}

gboolean k12text_dump_open(wtap_dumper *wdh, gboolean cant_seek, int *err) {

    if (cant_seek) {
        *err = WTAP_ERR_CANT_WRITE_TO_PIPE;
        return FALSE;
    }

    wdh->subtype_write = k12text_dump;
    wdh->subtype_close = k12text_dump_close;

    return TRUE;
}

int k12text_dump_can_write_encap(int encap) {
    switch (encap) {
        case WTAP_ENCAP_PER_PACKET:
	case WTAP_ENCAP_ETHERNET:
	case WTAP_ENCAP_MTP3:
	case WTAP_ENCAP_CHDLC:
	case WTAP_ENCAP_UNKNOWN:
		return 0;
	case WTAP_ENCAP_MTP2:
	case WTAP_ENCAP_ATM_PDUS:
	default:
		return WTAP_ERR_UNSUPPORTED_ENCAP;
    }
}

/*
 * We want to stop processing when we get to the end of the input.
 * (%option noyywrap is not used because if used then 
 * some flex versions (eg: 2.5.35) generate code which causes
 * warnings by the Windows VC compiler).
 */

int K12Text_wrap(void) {
    return 1;
}

